@@ -20,26 +20,9 @@ LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE."""
 # <=========>
-from functools import wraps
-from .server import *
 
-__version__ = "5.0.6"
+from .Scheduler import get_filename,dbg
 
+__version__ = "5.0.9"
 
-def func_time(f):
-    """
-    简单记录执行时间
-    :param f:
-    :return:
-    """
-
-    @wraps(f)
-    def wrapper(*args, **kwargs):
-        start = time.time()
-        result = f(*args, **kwargs)
-        end = time.time()
-        info = str(f.__name__) + ' took ' + str(end - start) + ' seconds '
-        print(info)
-        return result
-
-    return wrapper
+from .server import *
\ No newline at end of file
