@@ -8,6 +8,7 @@
 
 import time
 
+from .Scheduler import dbg
 from .construct_file import frame_constructor
 from .dbserver.base import Base
 from .dbserver.data_manager import data_manager
@@ -24,15 +25,15 @@ class Data(object):
     try:
         exec('from config import db_config')
         db_config = getattr(db_config, "db_config")
-        # print(db_config)
+        # dbg(db_config)
         if isinstance(db_config, dict):
             Base = data_manager(db_config)
             Base_pool['default'] = Base
             db_index = get_db_index(db_config)
             Base_pool[db_index] = Base
-        print('Auto init success!')
+        dbg('Auto init success!')
     except:
-        print('Did not find a db config file, need run Data.init(db_config) manually...')
+        dbg('Did not find a db config file, need run Data.init(db_config) manually...')
         # Base = None
 
     @staticmethod
@@ -47,7 +48,7 @@ class Data(object):
     @staticmethod
     def check_connections(base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         if base_id not in Data.Base_pool:
             return
         sql_pool = list(Data.Base_pool[base_id].threading_pool.values())
@@ -89,7 +90,7 @@ class Data(object):
     @staticmethod
     def add_new_sql(base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].new() if base_id in Data.Base_pool else None
 
     # create a new connect for an existed connection pool
@@ -97,7 +98,7 @@ class Data(object):
     @staticmethod
     def create(table, colums, comment='', show_sql=False, base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].create(table, colums, comment, show_sql) if base_id in Data.Base_pool else None
 
     # create table
@@ -105,7 +106,7 @@ class Data(object):
     @staticmethod
     def insert(table, params, show_sql=False, base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
 
         data = Data.Base_pool[base_id].insert(table, params, show_sql) if base_id in Data.Base_pool else None
         return data
@@ -116,7 +117,7 @@ class Data(object):
     def find(table, conditions, fields=('*',), or_cond=None, order=None, show_sql=False, base_id='default',
              show_manager_id=False, from_cache=False, for_update=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].find(table, conditions, or_cond, fields, order, show_sql, from_cache,
                                             for_update) if base_id in Data.Base_pool else None
 
@@ -126,7 +127,7 @@ class Data(object):
     def select(table, conditions, fields=('*',), or_cond=None, group=None, order=None, limit=None, show_sql=False,
                base_id='default', show_manager_id=False, from_cache=False, for_update=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].select(table, conditions, or_cond, fields, group, order, limit, show_sql,
                                               from_cache, for_update) if base_id in Data.Base_pool else None
 
@@ -146,8 +147,8 @@ class Data(object):
     @staticmethod
     def update(table, conditions, params=None, or_cond=None, show_sql=False, base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
-        # print(params)
+            dbg('本次任务通过', base_id, '执行')
+        # dbg(params)
         Data.Base_pool[base_id].update(table, conditions, or_cond, params,
                                        show_sql) if base_id in Data.Base_pool else None
         return
@@ -157,7 +158,7 @@ class Data(object):
     @staticmethod
     def delete(table, conditions, or_cond=None, show_sql=False, base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         data = Data.Base_pool[base_id].delete(table, conditions, or_cond,
                                               show_sql) if base_id in Data.Base_pool else None
         return data
@@ -167,7 +168,7 @@ class Data(object):
     @staticmethod
     def truncate(table, show_sql=False, base_id='default', show_manager_id=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].truncate(table, show_sql) if base_id in Data.Base_pool else None
 
     # truncate table
@@ -175,7 +176,7 @@ class Data(object):
     @staticmethod
     def query(sql, show_sql=False, base_id='default', show_manager_id=False, return_dict=False):
         if show_manager_id is True:
-            print('本次任务通过', base_id, '执行')
+            dbg('本次任务通过', base_id, '执行')
         return Data.Base_pool[base_id].query(sql, show_sql, return_dict) if base_id in Data.Base_pool else None
 
     # execute sql query
@@ -196,9 +197,9 @@ class Data(object):
     def map_all_db(base_id='default', show_manager_id=False, file_path='', file_name='db_frame.py'):
         try:
             if show_manager_id is True:
-                print('本次任务通过', base_id, '执行')
+                dbg('本次任务通过', base_id, '执行')
             if base_id not in Data.Base_pool:
-                print('base id not exist.. construct fail')
+                dbg('base id not exist.. construct fail')
                 return
             base_manager = Data.Base_pool[base_id]
             db_name = base_manager.t_data['database']
@@ -212,13 +213,13 @@ class Data(object):
                 res = Data.query('show full columns from ' + str(table_name), base_id=base_id)
                 table_index[table_name] = list(res)
                 table_index[table_name].append(table_info)
-            # pprint(table_index)
+            # pdbg(table_index)
             constructor = frame_constructor(db_name, table_index, file_path, file_name)
             constructor.dump()
-            print('create file success in %s' % file_path + file_name)
+            dbg('create file success in %s' % file_path + file_name)
             return table_index
         except Exception as e:
-            print(str(e))
+            dbg(str(e))
 
     # dump database as an Anduin-data-frame
 
